@@ -32,7 +32,7 @@ def convert_d3m_format(dataset_uri, output_folder, problem_config, suffix):
 
 def check_problem_config(problem_config):
     if problem_config['target_column'] is None:
-        raise ValueError('Parameter "target_column" not provided, but it is mandatory')
+        raise ValueError('Parameter "target" not provided, but it is mandatory')
 
     valid_task_keywords = {keyword for keyword in TaskKeywordBase.get_map().keys() if keyword is not None}
     if problem_config['task_keywords'] is None:
@@ -118,3 +118,10 @@ def create_d3m_problem(dataset, destination_path, problem_config):
 
     with open(join(destination_path, 'problemDoc.json'), 'w') as fout:
         json.dump(problem_json, fout, indent=4)
+
+
+def copy_folder(source_path, destination_path):
+    if exists(destination_path):
+        shutil.rmtree(destination_path)
+
+    shutil.copytree(source_path, destination_path)
